/* ICONS */
.icon_employment_new:before{
	content:"\f067";
}
.icon_employment_viewall:before,
.item_icon_employment:before{
	content:"\e2ea";
	font-family:uicons-regular-rounded !important;
	font-weight:400 !important;
}

/* ACTION TYPE ICONS */
.activity_icon_comment_employment:before{
	content:"\f075";
	font-family:'Font Awesome 6 Free';
}

/*BROWSE LISTING*/
.employments_browse > li{
	border-radius:var(--theme-widget-radius);
	background-color:var(--theme-list-background-color);
	border-width:1px;
	display:flex;
	flex-wrap:wrap;
	padding: 15px;
}
.employments_browse > li + li{
	margin-top:15px;
}
.employments_browse_info{
	flex:1;
	padding: 0px 0px 15px 0px;
}
.employments_browse_info_title{
	display:flex;
}
.employments_browse_info_title h3{
  margin:0;
	padding:0 0 10px;
	font-weight:600;
	flex:1;
	color: var(--theme-font-color);	
}
.employments_browse_info_title h3 a{
	color:var(--theme-font-color);
}
.employments_browse > li .content_approval_msg span{
	margin:10px 0 0;
}
.employments_browse_footer{
	border-radius:0 0 var(--theme-widget-radius) var(--theme-widget-radius);
	border-top-width:1px;
	padding: 15px 0px 0px 0px;
	width:100%;
	display:flex;
	justify-content:space-between;
}
.employments_browse_footer_info{
  font-size:var(--theme-font-size-small);
	color:var(--theme-font-color-light);
	padding-left:1px;
	display:flex;
}
[dir="rtl"] .employments_browse_footer_info{
	padding-left:0;
	padding-right:1px;
}
.employments_browse_footer_info > span + span:before{
	content:"-";
	margin:0 5px;
}
.employments_browse_footer_info i{
  margin-right:5px;
}
[dir="rtl"] .employments_browse_footer_info i{
  margin-right:0;
	margin-left:5px;	
}
.employments_browse_footer_info a{
	color:var(--theme-font-color);
}
.generic_layout_container .layout_employment_browse_search, 
.generic_layout_container .layout_employment_browse_menu_quick{
	margin-bottom:15px;
}
.employments_browse_footer .rating_star_show {
	margin-top: 0;
}
/*
VIEW EMPLOYMENT
Styles both the 'view employments' and the 'view employment listing'
pages, including the right-side gutter column by default.
*/
.employment_top h1{
	border-bottom-width:0.0625rem;
	padding-bottom:0.625rem;
}
.employment_entrylist_entry_date{
	color:var(--theme-font-color-light);
	margin-bottom:0.625rem;
}
.employment_rating_view_page {
  margin:0 0 0.625rem;
}
.employments_entrylist .profile_fields > ul{
	padding:10px 0;
}
.employment_entrylist_fields .profile_fields > ul > li > span:first-child{
	width:80px;
}
.employment_entrylist_fields .profile_fields > ul > li > span:last-child{
  color:var(--theme-button-background-color);
	font-weight:600;
	width:auto;
}
.employment_view .tip{
	margin-top:15px;
}
.employment_view .tip span{
	margin:0;
}
.employment_entrylist_entry_body{
	margin:15px 0;
}
.employment_entrylist_entry_body > h3{
	font-weight:600;
	border-bottom-width:1px;
	padding-bottom:10px;
	margin-bottom:10px;
}
.employment_entrylist_entry_body p{
	line-height:1.5em;
	margin-bottom:10px;
}
.employment_entrylist_entry_body br{
  display:none;
}
.employment_entrylist_entry_body ul,
.employment_entrylist_entry_body ol{
  margin-bottom:10px;
}
.employment_entrylist_entry_body img{
	max-width:100%;
}
.employment_entrylist_entry_body .employments_tags{
	overflow:hidden;
}
.employment_entrylist_entry_body .employments_tags > a{
	border-radius:5px;
	display:inline-block;
	margin:10px 4px 0 0;
	padding:2px 10px;
  float:none !important;
}
.employment_entrylis_options{
	border-top-width:1px;
	border-top-style:dashed;
	padding-top:10px;
}
.employment_entrylis_options > a{
  color:var(--theme-font-color);
  font-weight:var(--theme-font-weight-bold);
}
.layout_page_employment_index_view .layout_core_comments h3{
	display:none;
}
