INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES ('core_main_quickcreate_employment', 'employment', 'Post a New Listing', 'Employment_Plugin_Menus::canCreateEmployments', '{"route":"employment_general","action":"create","icon":"fi fi-rr-briefcase"}', 'core_main_quickcreate', '', 5);


UPDATE `engine4_core_menuitems` SET `params` = '{"route":"employment_general","icon":"fi fi-rr-briefcase"}' WHERE `engine4_core_menuitems`.`name` = 'core_main_employment';

UPDATE `engine4_core_menuitems` SET `description` = 'Post jobs, find talent, and manage opportunities 
' WHERE `engine4_core_menuitems`.`name` = 'core_main_employment';